#!/bin/sh
# Repackage upstream source to exclude non-distributable files
# should be called as "repack.sh --upstream-source <ver> <downloaded file>
# (for example, via uscan)

set -e
set -u

VER="$2"
FILE="$3"
PKG=`dpkg-parsechangelog|grep ^Source:|sed 's/^Source: //'`

REPACK_DIR="$PKG-$VER.orig" # DevRef § 6.7.8.2

echo -e "\nRepackaging $FILE\n"

REPACKED_ORIG=`echo $FILE | sed 's/\.orig\./+dfsg.1.orig./'`

DIR=`mktemp -d ./tmpRepackXXXXXX`
trap "rm -rf \"$DIR\"" QUIT INT EXIT

# Create an extra directory to cope with rootless tarballs
UP_BASE="$DIR/unpack"
mkdir "$UP_BASE"
tar xzf "$FILE" -C "$UP_BASE"

if [ `ls -1 "$UP_BASE" | wc -l` -eq 1 ]; then
	# Tarball does contain a root directory
	UP_BASE="$UP_BASE/`ls -1 "$UP_BASE"`"
fi

## Remove stuff

# remove the bench dir, it contains materials which cannot be
# redistribute properly (RSS feeds don't have licenses for example)
rm -rfv $UP_BASE/bench
# we will also get rid of the make benchmark
rm $UP_BASE/makebench.PL

# drop all references to bench
sed -i '\,bench, D' $UP_BASE/MANIFEST
sed -i '\,makebench.PL, D' $UP_BASE/MANIFEST

mv "$UP_BASE" "$DIR/$REPACK_DIR"

# Using a pipe hides tar errors!
tar cfC "$DIR/repacked.tar" "$DIR" "$REPACK_DIR"
gzip -9 -n < "$DIR/repacked.tar" > "$DIR/repacked.tar.gz"

mv "$DIR/repacked.tar.gz" "$REPACKED_ORIG"

echo "*** $REPACKED_ORIG ready"
